<?php
/* CentovaCast Source Control Script
 * Copyright 2007-2008, Centova Technologies Inc.
 * ===========================================================================
 *
 * This script allows the autoDJ for a stream to be controlled remotely, from
 * outside of the Centova Cast administrative interface.  Access to this
 * script could be provided to DJs to allow them to stop and start the autoDJ
 * before and after live streams.
 *
 * This is just one example of the flexibility of the Centova Cast XML API
 * which can be used to automate the management of Centova Cast streams.
 *
 */

// CONFIGURATION
// ===========================================================================
 
// Enter the URL to Centova Cast (i.e. http://www.example.com/cast/).
// If this script has been placed on the same server as Centova Cast, in the
// Centova Cast web root, leave blank to auto-detect.
$centovacast_url = 'http://cp.internet-radio.org.uk';
// ^^^ Change to your servers hostname

// Enter the username for the stream to control.
$stream_username = 'youtusername';
// ^^^ Enter your username here

// Enter the password for the stream to control (or leave blank and specify
// $admin_password below).
$stream_password = 'youradminpassword';
// ^^^ Enter your control panel (admin) password

// If you are the administrator of the Centova Cast server, you can
// alternately specify the Centova Cast 'admin' password here (leaving 
// $stream_password  blank above)
$admin_password = '';
// ^^^ Leave this blank!

// Enter the password which the DJ will use to login.  Obviously this should
// be different from your stream/admin password.
$dj_password = 'djsecret';
// ^^^ The password you want for DJ's (or you) to login and use this script.

// ===========================================================================
// Do not modify anything below this line unless you know what you're doing.
// ===========================================================================

// these files are included in the Centova Cast SDK, available from your
// client area at centova.com
require_once(dirname(__FILE__).'/class_HTTPRetriever.php');
require_once(dirname(__FILE__).'/ccapiclient.php');

function page_tpl($content) {
	echo '
<'.'?xml version="1.0" encoding="UTF-8"?'.'>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
<head>
	<meta http-equiv="content-type" content="text/html; charset=UTF-8" />
	<title>Source Control</title>
	<style type="text/css">
	body,td,th,input {
		font-family: Arial,sans-serif;
		font-size: 11px;
	}
	h1 {
		font-size: 12px;
	}
	</style>
</head>
<body>
<h1>Source Control</h1>
'.$content.'</body>
</html>
';
}

function page($type) {
	$args = func_get_args();
	$type = $args[0];
	
	$pages = array(
		'login'			=>'<form method="post" action="'.$_SERVER['PHP_SELF'].'">'.($args[1]?'<div style="color: red; margin-bottom: 8px">Login incorrect.</div>':'').'DJ Password: <input name="password" type="password" size="12" value="" /><br /><input type="submit" value="Login" /></form>',
		'statusfailed'	=>'Unable to retrieve stream status:<br />'.$args[1].'.<br /><br />If this is a 404 Not Found error, it is likely that you have set your $centovacast_url incorrectly in this script.  Otherwise, it is likely that your Centova Cast server is down or unreachable.',
		'index'			=>'Server status: <strong>'.($args[1]?'Online':'Offline').'</strong><br />AutoDJ status: <strong>'.($args[2]?'Online':'Offline').'</strong><br /><br /><a href="'.$_SERVER['PHP_SELF'].'?action='.($args[2]?'stop':'start').'">'.($args[2]?'Stop':'Start').' autoDJ</a> | <a href="'.$_SERVER['PHP_SELF'].'?action=logout">Logout</a><br />',
		'apiok'			=>'Request completed successfully: '.$args[1].'<br /><br /><a href="'.$_SERVER['PHP_SELF'].'">Return</a>',
		'apifailed'		=>'Request failed: '.$args[1].'<br /><br /><a href="'.$_SERVER['PHP_SELF'].'">Return</a>',
	);
	
	page_tpl($pages[$type]);
}


session_start();

// authenticate the DJ
$badlogin = false;
if ($_REQUEST['password']) {
	if ($_REQUEST['password']==$dj_password) {
		$_SESSION['authenticated'] = true;
	} else {
		$badlogin = true;
	}
}

if (!$_SESSION['authenticated']) {
	page('login',$badlogin);
	die;
}

// prepare our API client
$ccurl = strlen($centovacast_url) ? $centovacast_url : 'http' . ($_SERVER['HTTPS']?'s':'') . '://' . $_SERVER['HTTP_HOST'] . dirname($_SERVER['PHP_SELF']).'/';
$server = new CCServerAPIClient($ccurl);
$password = strlen($admin_password) ? 'admin|'.$admin_password : $stream_password;

if ($_REQUEST['action']) {
	switch($_REQUEST['action']) {
		case 'start':
		case 'stop':
			// start/stop the streaming source
			$arguments = array(
				'state'=>($_REQUEST['action']=='start') ? 'up' : 'down'
			);
			$server->call('switchsource',$stream_username,$password,$arguments);
			
			if (!$server->success) {
				page('apifailed',$server->error);
			} else {
				page('apiok',$server->message);
			}
			die;
			
		case 'logout':
			unset($_SESSION['authenticated']);
			session_destroy();
			session_write_close();
			
			Header("Location: ".$_SERVER['PHP_SELF']);
			die;

		default:
			break;
			
	}
}

// get the stream status
$arguments = array();
$server->call('getstatus',$stream_username,$password,$arguments);

if (!$server->success) {
	page_tpl('statusfailed',$server->error);
	die;
}

page('index',$server->data[0]['serverstate'],$server->data[0]['sourcestate']);
?>
